@@ -30,15 +30,16 @@ class DriverManager:
 
     def __get_chrome(self) -> webdriver:
         self.options = ChromeOptions()
+
         if self.headless:
             self.logger.debug('Starting chrome in headless mode')
+            self.options.headless = True
             self.options.add_argument('-headless')
             self.options.add_argument("-disable-gpu")
             self.options.add_argument("--no-sandbox")
             self.options.add_argument("--disable-dev-shm-usage")
-            self.options.binary_location = \
-                '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome'
+            self.options.add_argument("--remote-debugging-port=9222")
             return webdriver.Chrome(executable_path=ChromeDriverManager().install(),
-                                    chrome_options=self.options)
+                                    options=self.options)
         self.logger.debug('Starting chrome')
         return webdriver.Chrome(ChromeDriverManager().install())
