@@ -4,6 +4,7 @@ from Samuranium.Config import Config
 from Samuranium.DriverManager import DriverManager
 from Samuranium.Logger import Logger
 from Samuranium.WebElement import WebElement
+from Samuranium.WebElements import WebElements
 
 
 class Samuranium:
@@ -12,7 +13,6 @@ class Samuranium:
         self.config = Config()
         self.driver_manager = DriverManager(self.config, self.logger, headless=headless)
         self.selected_browser = self.config.browser
-
         self.max_wait_time = self.config.default_wait_time
         self.driver: webdriver = self.driver_manager.get_driver()
 
@@ -23,3 +23,6 @@ class Samuranium:
                      max_wait_time: float = None) -> WebElement:
         return WebElement(self, selector=selector, max_wait_time=max_wait_time)
 
+    def find_elements(self, selector: str = None):
+        return WebElements(self, selector=selector)
+
